@@ -167,7 +167,7 @@ class Player(VoiceProtocol):
         self._region = channel.rtc_region or "unknown_pylav"
         self._coordinates = REGION_TO_COUNTRY_COORDINATE_MAPPING.get(self._region, (0, 0))
         self._connected = False
-        self.connected_at = datetime.datetime.now(tz=datetime.timezone.utc)
+        self.connected_at = utcnow()
         self.last_track = None
         self.next_track = None
 
@@ -300,7 +300,7 @@ class Player(VoiceProtocol):
             if self.volume_filter.changed:
                 await self.node.send(op="volume", guildId=self.guild_id, volume=self.volume)
 
-        now_time = datetime.datetime.now(tz=datetime.timezone.utc)
+        now_time = utcnow()
         self.player_manager.client.scheduler.add_job(
             self.auto_dc_task,
             trigger="interval",
@@ -702,9 +702,7 @@ class Player(VoiceProtocol):
                     self,
                 )
                 return
-            LOGGER.trace(
-                "Auto save task for %s - Saving the player at %s", self, datetime.datetime.now(tz=datetime.timezone.utc)
-            )
+            LOGGER.trace("Auto save task for %s - Saving the player at %s", self, utcnow())
             await self.save()
 
     async def change_to_best_node(self, feature: str = None, ops: bool = True) -> Node | None:
@@ -1394,7 +1392,7 @@ class Player(VoiceProtocol):
         )
         self._connected = True
         self.connected_at = utcnow()
-        LOGGER.info("[Player-%s] Connected to voice channel", self.channel.guild.id)
+        LOGGER.debug("[Player-%s] Connected to voice channel", self.channel.guild.id)
 
     async def disconnect(self, *, force: bool = False, requester: discord.Member | None) -> None:
         try:
@@ -1402,7 +1400,7 @@ class Player(VoiceProtocol):
                 await self.save()
             await self.guild.change_voice_state(channel=None)
             self.node.dispatch_event(PlayerDisconnectedEvent(self, requester))
-            LOGGER.info("[Player-%s] Disconnected from voice channel", self.channel.guild.id)
+            LOGGER.debug("[Player-%s] Disconnected from voice channel", self.channel.guild.id)
         finally:
             self._connected = False
             self.queue.clear()
@@ -1462,7 +1460,7 @@ class Player(VoiceProtocol):
         if channel == self.channel:
             return
         old_channel = self.channel
-        LOGGER.info(
+        LOGGER.debug(
             "[Player-%s] Moving from %s to voice channel: %s", self.channel.guild.id, self.channel.id, channel.id
         )
         self.channel = channel
@@ -2308,8 +2306,8 @@ class Player(VoiceProtocol):
         if (v := effects.get("echo", None)) and (f := Echo.from_dict(v)) and f.changed:
             self._echo = f
         if current:
-            self.current = current
             current.timestamp = int(player.position)
+            self.queue.put_nowait([current], index=0)
         await self.change_to_best_node(ops=False)
         if self.has_effects:
             await self.node.filters(
@@ -2327,7 +2325,7 @@ class Player(VoiceProtocol):
             )
         if self.volume_filter.changed:
             await self.node.send(op="volume", guildId=self.guild_id, volume=self.volume)
-        if player.playing and not current:
+        if player.playing:
             await self.next(requester)  # type: ignore
         self.last_track = last_track
         self._restored = True
